@@ -1,4 +1,4 @@
-module Beaneater
+class Beaneater
   # Represents a stats hash with proper underscored keys
   class StatStruct < FasterOpenStruct
     # Convert a stats hash into a struct.
@@ -35,5 +35,11 @@ module Beaneater
     def keys
       @hash.keys.map { |k| k.to_s }
     end
+
+    # Returns the initialization hash
+    #
+    def to_h
+      @hash
+    end
   end # StatStruct
-end # Beaneater
\ No newline at end of file
+end # Beaneater
