@@ -29,8 +29,8 @@ class Beaneater
     # Delegates transmit to the connection object.
     #
     # @see Beaneater::Connection#transmit
-    def transmit(command, options={})
-      client.connection.transmit(command, options)
+    def transmit(command, **options)
+      client.connection.transmit(command, **options)
     end
 
     # Finds the specified beanstalk tube.
@@ -88,8 +88,8 @@ class Beaneater
     #   @pool.tubes.each {|t| puts t.name}
     #
     # @api public
-    def each
-      block_given? ? all.each(&Proc.new) : all.each
+    def each(&block)
+      all.each(&block)
     end
 
     # List of watched beanstalk tubes.
@@ -175,7 +175,7 @@ class Beaneater
     def use(tube)
       return tube if last_used == tube
       transmit("use #{tube}")
-      last_used = tube
+      self.last_used = tube
     rescue BadFormatError
       raise InvalidTubeName, "Tube cannot be named '#{tube}'"
     end
